
# Slot: has output


A chemical entity that is the output for the reaction

URI: [biolink:molecular_activity_has_output](https://w3id.org/biolink/vocab/molecular_activity_has_output)


## Domain and Range

[MolecularActivity](MolecularActivity.md) &#8594;  <sub>0..\*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has output](has_output.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002234 |
| **Close Mappings:** | | RO:0002353 |
|  | | RO:0002354 |
|  | | RTXKG1:output_of |
| **Narrow Mappings:** | | NCIT:R31 |
|  | | OBI:0000299 |
|  | | PathWhiz:has_right_element |
|  | | RO:0002296 |
|  | | RO:0002297 |
|  | | RO:0002298 |
|  | | RO:0002299 |
|  | | RO:0002588 |
|  | | RO:0004008 |

